summaryrefslogtreecommitdiffstats
path: root/ksnake/board.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commita13e26c2f1eb3c5be81acf4f571dd4bafac10199 (patch)
tree1f1d3e407ae668b1448847970b2f1b626083faf6 /ksnake/board.cpp
parent24c5cdc2737fe0044b11a12359606973eb93fc0b (diff)
downloadtdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.tar.gz
tdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ksnake/board.cpp')
-rw-r--r--ksnake/board.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/ksnake/board.cpp b/ksnake/board.cpp
index e9e44cd0..0959dee1 100644
--- a/ksnake/board.cpp
+++ b/ksnake/board.cpp
@@ -48,7 +48,7 @@ int Pos::price() const {
void Pos::setParent(Pos *p) {
_parent = p;
}
-Pos *Pos::tqparent() const {
+Pos *Pos::parent() const {
return(_parent);
}
Pos *Pos::listNext() {
@@ -241,7 +241,7 @@ int Board::getNextCloseTo(int s, int d, bool diag, int lastIndex)
if(list->index() == d) {
// Find first movement after root.
for(; ; list = p) {
- p = list->tqparent();
+ p = list->parent();
if(p == root) {
// This is our move.
int nextSq = list->index();
@@ -265,7 +265,7 @@ int Board::getNextCloseTo(int s, int d, bool diag, int lastIndex)
continue;
}
- int pi = list->tqparent() ? list->tqparent()->index() : lastIndex;
+ int pi = list->parent() ? list->parent()->index() : lastIndex;
if(pi != -1 && direction(pi, list->index()) !=
direction(list->index(), i)) {
pri += 10;
@@ -277,7 +277,7 @@ int Board::getNextCloseTo(int s, int d, bool diag, int lastIndex)
// Check price of found position with current one.
if(p->price() > pri) {
// We found a cheapear way to reach the same
// place, so let's change the tqparent and price of p.
p->setPrice(list->price() + 1);
p->setParent(list);
list->addList(p);
@@ -277,7 +277,7 @@ int Board::getNextCloseTo(int s, int d, bool diag, int lastIndex)
if(p->price() > pri) {
// We found a cheapear way to reach the same
- // place, so let's change the tqparent and price of p.
+ // place, so let's change the parent and price of p.
p->setPrice(list->price() + 1);
p->setParent(list);